==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Questo utente può effettuare il login',
    'activated_disabled_help_text' => 'Non puoi modificare lo stato di attivazione del proprio account.',
    'assets_user'       => 'Bene assegnato a :name',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di: user_count users. Tieni presente che non puoi modificare i tuoi attributi utente utilizzando questo modulo e devi modificare individualmente il tuo utente.',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più utenti contemporaneamente. Inserisci solo i campi che devi modificare. Tutti i campi lasciati vuoti rimarranno invariati.',
    'current_assets'    => 'Asset assegnato a questo utente',
    'clone'             => 'Clona Utente',
    'contact_user'      => 'Contatta :name',
    'edit'              => 'Modifica Utente',
    'filetype_info'     => 'I formati di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Storico per :name',
	'info'				=> 'Informazioni',
    'restore_user'		=> 'Clicca qui per ripristinarli.',
    'last_login'        => 'Ultimo accesso',
    'ldap_config_text'  => 'Le impostazioni di configurazione di LDAP possono essere trovate su Admin > Impostazioni. La posizione selezionata (facoltativa) verrà impostata per tutti gli utenti importati.',
    'print_assigned'    => 'Stampa tutti assegnati',
    'software_user'     => 'Software estratto a :name',
    'send_email_help'   => 'Devi fornire un indirizzo email all\'utente per inviare loro le credenziali. L\'inoltro delle credenziali via email avviene solo durante la creazione dell\'utente. La password è memorizzata in un hash unidirezionale e non può essere recuperata, una volta salvata.',
    'view_user'         => 'Visualizza Utente :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Le impostazioni correnti di amministratore consentono l\'esecuzione selettiva dell\'autenticazione a due fattori.',
    'two_factor_enrolled' => 'Apparecchio 2FA iscritto',
    'two_factor_active'   => '2FA attivo',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Questo utente può effettuare il login',
    'activated_disabled_help_text' => 'Non puoi modificare lo stato di attivazione del proprio account.',
    'assets_user'       => 'Bene assegnato a :name',
    'bulk_update_warn'	=> 'Stai per modificare le proprietà di: user_count users. Tieni presente che non puoi modificare i tuoi attributi utente utilizzando questo modulo e devi modificare individualmente il tuo utente.',
    'bulk_update_help'	=> 'Questo modulo consente di aggiornare più utenti contemporaneamente. Inserisci solo i campi che devi modificare. Tutti i campi lasciati vuoti rimarranno invariati.',
    'current_assets'    => 'Asset assegnato a questo utente',
    'clone'             => 'Clona Utente',
    'contact_user'      => 'Contatta :name',
    'edit'              => 'Modifica Utente',
    'filetype_info'     => 'I formati di file permessi sono png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, e rar.',
    'history_user'      => 'Storico per :name',
    'info'				=> 'Informazioni',
    'restore_user'		=> 'Clicca qui per ripristinarli.',
    'last_login'        => 'Ultimo accesso',
    'ldap_config_text'  => 'Le impostazioni di configurazione di LDAP possono essere trovate su Admin > Impostazioni. La posizione selezionata (facoltativa) verrà impostata per tutti gli utenti importati.',
    'print_assigned'    => 'Stampa tutti assegnati',
    'software_user'     => 'Software estratto a :name',
    'send_email_help'   => 'Devi fornire un indirizzo email all\'utente per inviare loro le credenziali. L\'inoltro delle credenziali via email avviene solo durante la creazione dell\'utente. La password è memorizzata in un hash unidirezionale e non può essere recuperata, una volta salvata.',
    'view_user'         => 'Visualizza Utente :name',
    'usercsv'           => 'CSV file',
    'two_factor_admin_optin_help' => 'Le impostazioni correnti di amministratore consentono l\'esecuzione selettiva dell\'autenticazione a due fattori.',
    'two_factor_enrolled' => 'Apparecchio 2FA iscritto',
    'two_factor_active'   => '2FA attivo',
    'user_deactivated'  => 'L\'utente è disattivato',
    'activation_status_warning' => 'Non cambiare lo stato di attivazione',
    'group_memberships_helpblock' => 'Solo i superamministratori possono modificare i membri del gruppo.',
    'superadmin_permission_warning' => 'Solo i superamministratori possono concedere il permesso di superamministratore a un altro utente.',
    'admin_permission_warning' => 'Solo gli utenti con diritti di amministratore o superiore possono nominare altri utenti come amministratore.',
    'remove_group_memberships' => 'Rimuove Membri del Gruppo',
    'warning_deletion' => 'ATTENZIONE:',
    'warning_deletion_information' => 'Stai per eliminare :count utenti listati qui sotto. I superamministratori sono evidenziati in rosso.',
    'update_user_asssets_status' => 'Aggiorna tutti i beni per questi utenti a questo stato',
    'checkin_user_properties' => 'Esegui il check-in di tutte le proprietà associate a questi utenti',
];
